"""
.. include:: ../README.md
"""

from __future__ import annotations

__all__ = [
    # submodules (with sub-submodules)
    "json_serialize",
    "logger",
    "math",
    "misc",
    "nbutils",
    "web",
    # submodules
    "collect_warnings",
    "console_unicode",
    "dbg",
    "dictmagic",
    "errormode",
    "group_equiv",
    "interval",
    "jsonlines",
    "kappa",
    "mlutils",
    "parallel",
    "spinner",
    "statcounter",
    "sysinfo",
    "tensor_info",
    "tensor_utils",
    "timeit_fancy",
    "validate_type",
]
